@@ -1,5 +1,5 @@
-from maths import *
+
 class billpy:
     def findtax(percent,netamount):
-        taxamount=mul(netamount,div(percent,100))
+        taxamount=netamount*(percent/100)
         return taxamount
\ No newline at end of file
